
===========
Mars24 Python library
===========

The marstime package implements the Mars24 algorithm based on the Allison and McEwan(2000) paper. Details can be found at http://www.giss.nasa.gov/tools/mars24/ . This package is provided to aid transition from the old name (Mars24) to the new name (marstime). The package simply installs and imports marstime.

Christopher Lee, 2012
